#
# spec file for package perl-Package-Stash
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Package-Stash
Name:           perl-Package-Stash
Version:        0.40
Release:        1.11
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Routines for manipulating stashes
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/E/ET/ETHER/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(CPAN::Meta::Check) >= 0.011
BuildRequires:  perl(CPAN::Meta::Requirements)
BuildRequires:  perl(Dist::CheckConflicts) >= 0.02
BuildRequires:  perl(Module::Implementation) >= 0.06
BuildRequires:  perl(Package::Stash::XS) >= 0.26
BuildRequires:  perl(Test::Fatal)
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Needs)
Requires:       perl(Dist::CheckConflicts) >= 0.02
Requires:       perl(Module::Implementation) >= 0.06
Requires:       perl(Package::Stash::XS) >= 0.26
Recommends:     perl(Package::Stash::XS) >= 0.26
%{perl_requires}

%description
Manipulating stashes (Perl's symbol tables) is occasionally necessary, but
incredibly messy, and easy to get wrong. This module hides all of that
behind a simple API.

NOTE: Most methods in this class require a variable specification that
includes a sigil. If this sigil is absent, it is assumed to represent the
IO slot.

Due to limitations in the typeglob API available to perl code, and to
typeglob manipulation in perl being quite slow, this module provides two
implementations - one in pure perl, and one using XS. The XS implementation
is to be preferred for most usages; the pure perl one is provided for cases
where XS modules are not a possibility. The current implementation in use
can be set by setting '$ENV{PACKAGE_STASH_IMPLEMENTATION}' or
'$Package::Stash::IMPLEMENTATION' before loading Package::Stash (with the
environment variable taking precedence), otherwise, it will use the XS
implementation if possible, falling back to the pure perl one.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING README
%license LICENSE

%changelog
* Tue Feb 22 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.40
  see /usr/share/doc/packages/perl-Package-Stash/Changes
  0.40      2022-02-21 05:38:38Z
  - update bundled version of ExtUtils::HasCompiler, for new new Apple
    include paths
* Mon Nov 23 2020 Tina Müller <timueller+perl@suse.de>
- updated to 0.39
  see /usr/share/doc/packages/perl-Package-Stash/Changes
  0.39      2020-11-22 01:26:43Z
  - updated distribution metadata and packaging
  - configuration phase now uses ExtUtils::HasCompiler
* Mon Dec 31 2018 Stephan Kulow <coolo@suse.com>
- updated to 0.38
  see /usr/share/doc/packages/perl-Package-Stash/Changes
  0.38      2018-12-31 03:25:07Z
  - avoid new warning in 5.21.x regarding too many arguments for
    printf/sprintf (Renée Bäcker)
  - canonical repository moved to https://github.com/moose/Package-Stash
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.37
  see /usr/share/doc/packages/perl-Package-Stash/Changes
  0.37  2014-09-21
  - fix spurious warning in taint mode (Niko Tyni, #12)
* Thu Jun 26 2014 lchiquitto@suse.com
- remove outdated perl-Package-Stash-old_Test-More.patch from
  package sources
* Fri Oct  4 2013 coolo@suse.com
- updated to 0.36
  - support building with PUREPERL_ONLY
* Fri Jul 26 2013 coolo@suse.com
- updated to 0.35
  - remove old deprecated api
- remove outdated perl-Package-Stash-old_Test-More.patch
* Tue Jun 11 2013 coolo@suse.com
- updated to 0.34
  - support anonymous stashes on newer perl versions
  - prevent harmful effects from invalid settings for
    $ENV{PACKAGE_STASH_IMPLEMENTATION}
  - switch to Module::Implementation
* Wed Feb 29 2012 ro@suse.de
- updated perl-Package-Stash-old_Test-More.patch
* Wed Oct 26 2011 tabraham@novell.com
- updated to 0.33
  - add conflict on MooseX::Method::Signatures 0.36 (ether)
- updated to 0.32 2011-09-05
  - bring the behavior of has_symbol for nonexistant scalars into
    line with the XS version
  - invalid package names (for instance, Foo::Bar) are not allowed
  - invalid stash entry names (anything containing ::) are not allowed
- updated to 0.31 2011-08-08
  - fix ->add_symbol('$foo', qr/sdlfk/) on 5.12+
  - fix ->add_symbol('$foo', \v1.2.3) on 5.10+
- updated to 0.30 2011-07-21
  - fix compiler detection in Makefile.PL (ribasushi)
* Sat Jun  4 2011 lars@linux-schulserver.de
- update to 0.29, see Changes:
  + no, *really* skip the package-stash-conflict script
- fix build on distributions with old Test::More module
  ( perl-Package-Stash-old_Test-More.patch )
- files in /usr/bin should be executable
* Thu Mar 31 2011 coolo@novell.com
- update to 0.28, see Changes:
  - META.json fixes (mst)
  - also skip the package-stash-conflicts script (Father Chrysostomos)
  - make the namespace cache lazy and weak, in case the stash is deleted
  - but, this doesn't work on 5.8, so disable the namespace caching
    entirely there
  - make the leak tests author-only, since some smokers run release tests
  - make the leak tests release-only, since they keep randomly failing on
    platforms i don't have access to. people are encouraged to submit
    patches for these if they are affected.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Nov 11 2010 chris@computersalat.de
- fix build for 1110
  o Build_n_Test patch
* Thu Nov 11 2010 chris@computersalat.de
- update to 0.13
  - revert the vivification changes for now, to get an actual release out
    with Test::Fatal
- 0.12-TRIAL  2010-10-27
  - actually include the conflict stuff in the release (bah)
- 0.11-TRIAL  2010-10-27
  - conflict on mx-role-withoverloading too
- 0.10-TRIAL  2010-10-27
  - only do the weird ISA special-casing on perl versions where it's broken
- 0.09-TRIAL  2010-10-27
  - clean up the vivication code a lot, make it behave more sanely
  - use Test::Fatal instead of Test::Exception (Justin Hunter)
- noarch pkg
* Fri Oct  8 2010 dmueller@suse.de
- update to 0.08:
  - oops, accidentally included some experimental changes in that last
    release, that break things
  - non-dev release
  - re-enable the caching of the stash, since I can't reproduce the bug
    at all
* Tue Aug 31 2010 pascal.bleser@opensuse.org
- update to 0.05:
  * bump Test::More requirement for done_testing
- changes from 0.04:
  * get_package_symbol now doesn't autovivify stash entries. A new method get_or_add_package_symbol can now be used for that behavior.
  * update %%DB::sub on add_package_symbol
* Sun Jun 13 2010 pascal.bleser@opensuse.org
- initial package (0.03)
